unit ViewForm.Main;

// Define TIOPF directive if tiOPF installed (www.tiopf.com)
{.$DEFINE TIOPF}

interface

uses
  Winapi.Windows
 ,Winapi.Messages
 ,System.SysUtils
 ,System.Variants
 ,System.Classes
 ,Vcl.Graphics
 ,Vcl.Controls
 ,Vcl.Forms
 ,Vcl.Dialogs
 ,Vcl.ExtCtrls
 ,Vcl.StdCtrls
 ,Vcl.ImgList
 ;

type
  TViewFormMain = class(TForm)
    CompressCheckBox : TCheckBox;
    EncryptComboBox  : TComboBox;
    ExploreButton    : TButton;
    FileBrowseButton : TButton;
    FileNameEdit     : TEdit;
    GoDirectButton   : TButton;
    GoTiOPFButton    : TButton;
    ImageList        : TImageList;
    Label1           : TLabel;
    Label2           : TLabel;
    LogMemo          : TMemo;
    OpenDialog       : TOpenDialog;
    TiOPFLabel       : TLabel;
    TopPanel         : TPanel;
    ZlibTypeComboBox : TComboBox;
    procedure FileBrowseButtonClick(Sender: TObject);
    procedure GoTiOPFButtonClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure GoDirectButtonClick(Sender: TObject);
    procedure ExploreButtonClick(Sender: TObject);
  private
    procedure LogMsg( const AMsg: string );
  public
  end;

var
  ViewFormMain: TViewFormMain;

implementation
uses
  Model.ZlibDemo
{$IFDEF TIOPF}
 ,tiEncrypt
{$ENDIF}
 ,System.ZLib
 ,ShellAPI
 ;

{$R *.dfm}

procedure TViewFormMain.ExploreButtonClick(Sender: TObject);
begin
  ShellExecute(0,'explore',PWideChar(ExtractFilePath(FileNameEdit.Text)),'','',SW_SHOWNORMAL);
end;

procedure TViewFormMain.FileBrowseButtonClick(Sender: TObject);
begin
  OpenDialog.FileName   := FileNameEdit.Text;
  if Length(FileNameEdit.Text) > 0 then
    OpenDialog.InitialDir := ExtractFilePath(FileNameEdit.Text)
  else
    OpenDialog.InitialDir := ExtractFilePath(ParamStr(0)) + 'Data';
  if OpenDialog.Execute then
    FileNameEdit.Text := OpenDialog.FileName;
end;

procedure TViewFormMain.FormCreate(Sender: TObject);
begin
  FileNameEdit.Text          := ExtractFilePath(ParamStr(0)) + 'Data\FileToCompress.ext';
  ZlibTypeComboBox.ItemIndex := 2;
{$IFDEF TIOPF}
  CompressCheckBox.Enabled   := True;
  CompressCheckBox.Checked   := True;
  gEncryptFactory.AssignEncryptionTypes(EncryptComboBox.Items);    //tiOPF
  EncryptComboBox.Enabled    := True;
  EncryptComboBox.ItemIndex  := 0;
  GoTiOPFButton.Enabled      := True;
  TiOPFLabel.Visible         := False;
{$ENDIF}
end;

procedure TViewFormMain.GoDirectButtonClick(Sender: TObject);
var
  lZlibDemo : TZlibDemo;
begin
  if not FileExists(FileNameEdit.Text) then
    LogMsg('It might help if the file actually existed')
  else
  begin
    lZlibDemo             := TZlibDemo.Create;
    lZlibDemo.EncryptType := EncryptComboBox.Text;
    lZlibDemo.OnLogMsg    := LogMsg;
    try
      lZlibDemo.ExecuteDirect(FileNameEdit.Text, System.ZLib.TZCompressionLevel(ZlibTypeComboBox.ItemIndex));
    finally
      lZlibDemo.Free;
    end;
  end;
end;

procedure TViewFormMain.GoTiOPFButtonClick(Sender: TObject);
{$IFDEF TIOPF}
var
  lZlibDemo : TZlibDemo;
{$ENDIF}
begin
{$IFDEF TIOPF}
  if not FileExists(FileNameEdit.Text) then
    Exit; //===========>

  lZlibDemo             := TZlibDemo.Create;
  lZlibDemo.Compress    := CompressCheckBox.Checked;
  lZlibDemo.EncryptType := EncryptComboBox.Text;
  lZlibDemo.OnLogMsg    := LogMsg;
  try
    lZlibDemo.ExecuteTiOPF(FileNameEdit.Text);
  finally
    lZlibDemo.Free;
  end;
{$ENDIF}
end;

procedure TViewFormMain.LogMsg(const AMsg: string);
begin
  LogMemo.Lines.Append( Format('%s %s',[FormatDateTime('dd/mm/yy hh:nn:ss.zzz',Now), AMsg]) );
end;

end.
